AlignmentInfo class

Constructors

AlignmentInfo({required String? checkedPackage, required List<SoFile> soFiles})
const
AlignmentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

checkedPackage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soFiles → List<SoFile>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited