AndroidInfo class

Constructors

AndroidInfo({required String? checkedPackage, required Object? compileSdk, required String? agp, required String? ndk})
const
AndroidInfo.fromJson(Map<String, dynamic> json)
factory

Properties

agp → String?
final
checkedPackage → String?
final
compileSdk → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
ndk → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited