NativeIosResult class
Whether a plugin has native iOS code that could be blocked by the CocoaPods deadline, and why not when it doesn't (SPEC e2-s1 rework 2).
Constructors
- NativeIosResult({required bool nativeIos, required String? reason})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited