platformInfo method
The declared entry for platform, or null when this package's pubspec
doesn't list it at all.
Implementation
PluginPlatformInfo? platformInfo(String platform) => platforms[platform];
The declared entry for platform, or null when this package's pubspec
doesn't list it at all.
PluginPlatformInfo? platformInfo(String platform) => platforms[platform];