PackageScore class

Tags, like count and 30-day download count for a package's latest version, from GET /api/packages/<name>/score (SPEC 3.1.3).

Constructors

PackageScore({required List<String> tags, required int likeCount, required int downloadCount30Days})
const

Properties

downloadCount30Days → int
final
hashCode → int
The hash code for this object.
no setterinherited
likeCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited