PluginPlatformInfo class

A single platform's entry under a plugin's pubspec.flutter.plugin.platforms map.

Constructors

PluginPlatformInfo({String? defaultPackage, String? pluginClass, bool ffiPlugin = false})
const
PluginPlatformInfo.fromJson(Map<String, dynamic> json)
factory

Properties

declaresNativeImplementation → bool
True when this platform entry itself declares a native implementation — not a federated default_package and not a dartPluginClass-only Dart implementation (SPEC e2-s1 iOS-resolution rework).
no setter
defaultPackage → String?
The federated implementation package declared for this platform, if any.
final
ffiPlugin → bool
Whether this platform declares a native FFI plugin directly.
final
hashCode → int
The hash code for this object.
no setterinherited
pluginClass → String?
A native plugin class declared directly on this platform (as opposed to dartPluginClass, which is Dart-only).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited