pluginClass property
A native plugin class declared directly on this platform (as opposed to
dartPluginClass, which is Dart-only).
Implementation
final String? pluginClass;
A native plugin class declared directly on this platform (as opposed to
dartPluginClass, which is Dart-only).
final String? pluginClass;