PubDevApiException class

Thrown when a pub.dev API call does not return HTTP 200.

Implemented types

Constructors

PubDevApiException(Uri uri, int statusCode)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
uri → Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited