SoFile class

Constructors

SoFile({required String path, required bool aligned, required int? minAlign})
const
SoFile.fromJson(Map<String, dynamic> json)
factory

Properties

aligned → bool
final
hashCode → int
The hash code for this object.
no setterinherited
minAlign → int?
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited