isAndroidGradleFilePath function
Whether path is one of the two Gradle files a plugin's Android build
settings can be declared in, at the archive root.
Implementation
bool isAndroidGradleFilePath(String path) =>
path == 'android/build.gradle' || path == 'android/build.gradle.kts';