NativeIosResult class

Whether a plugin has native iOS code that could be blocked by the CocoaPods deadline, and why not when it doesn't (SPEC e2-s1 rework 2).

Constructors

NativeIosResult({required bool nativeIos, required String? reason})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativeIos → bool
final
reason → String?
Set only when nativeIos is false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited