Snapshot class
Constructors
-
Snapshot({required int schemaVersion, required String generatedAt, required DiscoveryInfo discovery, required List<
PluginEntry> plugins}) -
const
-
Snapshot.fromJson(Map<
String, dynamic> json) -
factory
Properties
- discovery → DiscoveryInfo
-
final
- generatedAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
plugins
→ List<
PluginEntry> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited